@@ -5,5 +5,5 @@
 # All rights reserved.
 #
 
-__version__ = "1.3.4"
-DATE = "2020-Mar-11"
+__version__ = "1.3.5"
+DATE = "2020-dec-22"
